'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
const beforeMessage = 'You need a newline or comment before an `it` or `test` block when it comes after another expression';
const expressionName = node => node.expression && node.expression.callee && node.expression.callee.name;
const isTestBlock = node => expressionName(node) === 'test' || expressionName(node) === 'it';
exports.default = {
    meta: {
        docs: {
            description: 'Enforces at least a line of padding before test blocks within a describe',
            category: 'Formatting',
            recommended: true,
        },
        fixable: 'whitespace',
        schema: [],
    },
    beforeMessage,
    create(context) {
        const filePath = context && context.getFilename();
        const isTestFile = filePath.includes('test') ||
            filePath.includes('spec') ||
            filePath.includes('<input>');
        return {
            ExpressionStatement(node) {
                if (!isTestFile || !isTestBlock(node)) {
                    return;
                }
                utils_1.padBefore({ context, node, beforeMessage });
            },
        };
    },
};
